Attribute VB_Name = "modPluginHandling"
' This module reads the plugin, performs the parsing and writes the result
' in the global variables.

Option Explicit

                                            'In this column is a short description
                                            'of the meaning of the variables. You
                                            'find more information about them on the
                                            'project web site or the readme.
    
Public plugin_filename As String
Public plugin_id As String                  'Unique ID of the ATK plugin
Public plugin_name As String                'Plugin name of the ATK plugin
Public plugin_family As String              'Plugin family of the ATK plugin
Public plugin_by As String                  'Who created the ATK plugin
Public plugin_create_date As String         'When was the ATK plugin created
Public plugin_updated_by As String          'Who updated the ATK plugin
Public plugin_update_date As String         'When was the ATK plugin updated
Public plugin_version As String             'Which version of the plugin is it
Public plugin_protocol As String            'Which protocol does the plugin use
Public plugin_port As String                'Which port does the ATK plugin use
Public plugin_request As String             'Which requests shall the plugin do
Public plugin_trigger As String             'Which trigger indicates the flaw
Public plugin_comment As String             'Some words about the ATK plugin

Public bug_published_by As String           'Who published the bug first
Public bug_date_published As String         'Date when the bug was first published
Public bug_advisory As String               'What is the name and URL of the advisory
Public bug_affected As String               'Which systems and solutions are affected
Public bug_not_affected As String           'Which systems and solutions are not affected
Public bug_vulnerability_class As String    'The class of the vulnerability
Public bug_local As String
Public bug_remote As String
Public bug_description As String            'The description of the vulnerability
Public bug_solution As String               'The solution(s) for the vulnerability
Public bug_fixing_time As String            'The time needed to fix the bug (e.g. hours)
Public bug_exploit_availability As String   'The existence of an exploit
Public bug_exploit_url As String            'The URL of the exploit
Public bug_severity As String               'The severity of the vulnerability
Public bug_popularity As String             'The popularity of the vulnerability (1 to 10)
Public bug_simplicity As String             'The simplicity of the bug (1 to 10)
Public bug_impact As String                 'The impact level of the bug (1 to 10)
Public bug_risk As String                   'The rist of the bug (1 to 10)
Public bug_nessus_risk As String            'The risk level of the bug by Nessus
Public bug_iss_scanner_rating As String     'The risk level by ISS Scanners
Public bug_netrecon_rating As String        'The risk level by Symantec NetRecon
Public bug_check_tool As String             'List of tools that are able to check the bug

Public source_cve As String                 'The CAN or CVE number of the vulnerability
Public source_securityfocus_bid As String   'The unique SecurityFocus/Bugtraq ID
Public source_secunia_id As String          'The unique Secunia ID of the vulnerability
Public source_securiteam As String
Public source_scipid As String              'The unique scipID of the vulnerability
Public source_tecchannel_id As String       'The unique tecchannel ID
Public source_heise_news As String          'The unique Heise News
Public source_heise_security As String      'The unique Heise Security
Public source_aerasec_id As String          'The unique AeraSec ID
Public source_nessus_id As String           'The unique Nessus ID of the vulnerability
Public source_snort_id As String            'The unique Snort ID of the vulnerability
Public source_literature As String          'List of books about the flaw
Public source_misc As String                'List of other sources (e.g. TV shows)

' *******************************************************************
' * Reset all plugin variables. This is usually done before new     *
' * data is read. Old "garbage" is prevented and the software don't *
' * need so much ressources during runtime.                         *
' *******************************************************************

Public Sub ClearAllPluginVariables()
    plugin_id = vbNullString
    plugin_name = vbNullString
    plugin_family = vbNullString
    plugin_by = vbNullString
    plugin_create_date = vbNullString
    plugin_updated_by = vbNullString
    plugin_update_date = vbNullString
    plugin_version = vbNullString
    plugin_protocol = vbNullString
    plugin_port = vbNullString
    plugin_request = vbNullString
    plugin_trigger = vbNullString
    plugin_comment = vbNullString
    
    bug_published_by = vbNullString
    bug_date_published = vbNullString
    bug_advisory = vbNullString
    bug_affected = vbNullString
    bug_not_affected = vbNullString
    bug_vulnerability_class = vbNullString
    bug_local = vbNullString
    bug_remote = vbNullString
    bug_description = vbNullString
    bug_solution = vbNullString
    bug_fixing_time = vbNullString
    bug_exploit_availability = vbNullString
    bug_exploit_url = vbNullString
    bug_severity = vbNullString
    bug_popularity = vbNullString
    bug_simplicity = vbNullString
    bug_impact = vbNullString
    bug_risk = vbNullString
    bug_nessus_risk = vbNullString
    bug_iss_scanner_rating = vbNullString
    bug_netrecon_rating = vbNullString
    bug_check_tool = vbNullString
    
    source_cve = vbNullString
    source_securityfocus_bid = vbNullString
    source_secunia_id = vbNullString
    source_securiteam = vbNullString
    source_scipid = vbNullString
    source_tecchannel_id = vbNullString
    source_heise_news = vbNullString
    source_heise_security = vbNullString
    source_aerasec_id = vbNullString
    source_nessus_id = vbNullString
    source_snort_id = vbNullString
    source_literature = vbNullString
    source_misc = vbNullString
End Sub

Public Sub ReadATKPluginFromFile(Filename As String)
    Dim Temp As String          'The temporary file output
    Dim PluginContent As String 'The plugin content itself
    Dim TempArray() As String   'A temporary array for the splitting and parsing
    
    'Check the existence of the file
    On Error Resume Next
    If Len(Dir(PluginDirectory & "\" & Filename)) < 1 Then
        MsgBox "File does not exist!"
        Exit Sub
    End If
   
    'Open and read the plugin file
    Open PluginDirectory & "\" & Filename For Input As 1
        Do While Not EOF(1)
            Line Input #1, Temp
                PluginContent = PluginContent & Temp
        Loop
    Close
        
    'Clear the values from the last plugin to prevent misunderstandings
    Call ClearAllPluginVariables    'Plugin variables itself
    'Call ClearAllResponseVariables  'Plugin last response
    
    'Get the data fields and write them into the public variables
    TempArray = Split(PluginContent, "<plugin_id>")
    TempArray = Split(TempArray(1), "</plugin_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_id = TempArray(0)
    End If
        
    TempArray = Split(PluginContent, "<plugin_name>")
    TempArray = Split(TempArray(1), "</plugin_name>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_name = TempArray(0)
    Else
        Call PluginReadError(Filename, "plugin_name")
    End If

    TempArray = Split(PluginContent, "<plugin_family>")
    TempArray = Split(TempArray(1), "</plugin_family>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_family = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_by>")
    TempArray = Split(TempArray(1), "</plugin_by>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_by = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_create_date>")
    TempArray = Split(TempArray(1), "</plugin_create_date>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_create_date = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_updated_by>")
    TempArray = Split(TempArray(1), "</plugin_updated_by>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_updated_by = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_update_date>")
    TempArray = Split(TempArray(1), "</plugin_update_date>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_update_date = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_version>")
    TempArray = Split(TempArray(1), "</plugin_version>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_version = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<plugin_protocol>")
    TempArray = Split(TempArray(1), "</plugin_protocol>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_protocol = TempArray(0)
    Else
        Call PluginReadError(Filename, "plugin_protocol")
    End If

    TempArray = Split(PluginContent, "<plugin_port>")
    TempArray = Split(TempArray(1), "</plugin_port>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_port = Val(TempArray(0))
    Else
        Call PluginReadError(Filename, "plugin_port")
    End If
    
    TempArray = Split(PluginContent, "<plugin_request>")
    TempArray = Split(TempArray(1), "</plugin_request>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_request = TempArray(0)
    Else
        Call PluginReadError(Filename, "plugin_request")
    End If
    
    TempArray = Split(PluginContent, "<plugin_trigger>")
    TempArray = Split(TempArray(1), "</plugin_trigger>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_trigger = TempArray(0)
    End If
                
    TempArray = Split(PluginContent, "<plugin_comment>")
    TempArray = Split(TempArray(1), "</plugin_comment>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        plugin_comment = TempArray(0)
    End If
                
    TempArray = Split(PluginContent, "<bug_published_by>")
    TempArray = Split(TempArray(1), "</bug_published_by>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_published_by = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_date_published>")
    TempArray = Split(TempArray(1), "</bug_date_published>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_date_published = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_advisory>")
    TempArray = Split(TempArray(1), "</bug_advisory>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_advisory = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_affected>")
    TempArray = Split(TempArray(1), "</bug_affected>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_affected = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_not_affected>")
    TempArray = Split(TempArray(1), "</bug_not_affected>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_not_affected = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_local>")
    TempArray = Split(TempArray(1), "</bug_local>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_local = TempArray(0)
    End If
        
    TempArray = Split(PluginContent, "<bug_remote>")
    TempArray = Split(TempArray(1), "</bug_remote>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_remote = TempArray(0)
    End If
        
    TempArray = Split(PluginContent, "<bug_vulnerability_class>")
    TempArray = Split(TempArray(1), "</bug_vulnerability_class>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_vulnerability_class = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_description>")
    TempArray = Split(TempArray(1), "</bug_description>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_description = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_solution>")
    TempArray = Split(TempArray(1), "</bug_solution>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_solution = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_fixing_time>")
    TempArray = Split(TempArray(1), "</bug_fixing_time>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_fixing_time = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_exploit_availability>")
    TempArray = Split(TempArray(1), "</bug_exploit_availability>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_exploit_availability = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_exploit_url>")
    TempArray = Split(TempArray(1), "</bug_exploit_url>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_exploit_url = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<bug_severity>")
    TempArray = Split(TempArray(1), "</bug_severity>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_severity = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<bug_popularity>")
    TempArray = Split(TempArray(1), "</bug_popularity>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_popularity = Val(TempArray(0))
    End If

    TempArray = Split(PluginContent, "<bug_simplicity>")
    TempArray = Split(TempArray(1), "</bug_simplicity>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_simplicity = Val(TempArray(0))
    End If

    TempArray = Split(PluginContent, "<bug_impact>")
    TempArray = Split(TempArray(1), "</bug_impact>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_impact = Val(TempArray(0))
    End If

    TempArray = Split(PluginContent, "<bug_risk>")
    TempArray = Split(TempArray(1), "</bug_risk>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_risk = Val(TempArray(0))
    End If

    TempArray = Split(PluginContent, "<bug_nessus_risk>")
    TempArray = Split(TempArray(1), "</bug_nessus_risk>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_nessus_risk = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<bug_iss_scanner_rating>")
    TempArray = Split(TempArray(1), "</bug_iss_scanner_rating>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_iss_scanner_rating = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<bug_netrecon_rating>")
    TempArray = Split(TempArray(1), "</bug_netrecon_rating>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_netrecon_rating = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<bug_check_tool>")
    TempArray = Split(TempArray(1), "</bug_check_tool>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        bug_check_tool = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<source_cve>")
    TempArray = Split(TempArray(1), "</source_cve>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_cve = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<source_securityfocus_bid>")
    TempArray = Split(TempArray(1), "</source_securityfocus_bid>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_securityfocus_bid = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_secunia_id>")
    TempArray = Split(TempArray(1), "</source_secunia_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_secunia_id = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_securiteam>")
    TempArray = Split(TempArray(1), "</source_securiteam>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_securiteam = TempArray(0)
    End If
        
    TempArray = Split(PluginContent, "<source_scipid>")
    TempArray = Split(TempArray(1), "</source_scipid>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_scipid = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_tecchannel_id>")
    TempArray = Split(TempArray(1), "</source_tecchannel_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_tecchannel_id = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_heise_news>")
    TempArray = Split(TempArray(1), "</source_heise_news>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_heise_news = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_heise_security>")
    TempArray = Split(TempArray(1), "</source_heise_security>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_heise_security = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_aerasec_id>")
    TempArray = Split(TempArray(1), "</source_aerasec_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_aerasec_id = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_nessus_id>")
    TempArray = Split(TempArray(1), "</source_nessus_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_nessus_id = TempArray(0)
    End If
    
    TempArray = Split(PluginContent, "<source_snort_id>")
    TempArray = Split(TempArray(1), "</source_snort_id>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_snort_id = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<source_literature>")
    TempArray = Split(TempArray(1), "</source_literature>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_literature = TempArray(0)
    End If

    TempArray = Split(PluginContent, "<source_misc>")
    TempArray = Split(TempArray(1), "</source_misc>")
    If Len(TempArray(0)) <> Len(PluginContent) Then
        source_misc = TempArray(0)
    End If

End Sub

Private Sub PluginReadError(ByRef Filename As String, ByRef Position As String)
    'Write error message if something went wrong during parsing of the plugin file
    MsgBox ("Could not find the data field '" & Position & "'" & vbCrLf & _
        "in the plugin '" & Filename & "'." & vbCrLf & vbCrLf & _
        "The plugin seems to be broken and can't be used." & vbCrLf & _
        "Please check this manually."), _
        vbInformation, "Attack Tool Kit Plugin parsing error"
End Sub

Public Sub WritePluginToFile(ByRef Filename As String)
    Dim PluginContent As String
    Dim PluginContentArray() As String
    Dim i As Integer
    
    'Prepare the comment
    If LenB(plugin_comment) = 0 Then
        plugin_comment = "This plugin was written with the ATK Attack Editor."
    End If
    
    'Collect the whole data
    PluginContent = _
        "<plugin_id>" & plugin_id & "</plugin_id>" & vbCrLf & _
        "<plugin_name>" & plugin_name & "</plugin_name>" & vbCrLf & _
        "<plugin_family>" & plugin_family & "</plugin_family>" & vbCrLf & _
        "<plugin_by>" & plugin_by & "</plugin_by>" & vbCrLf & _
        "<plugin_create_date>" & plugin_create_date & "</plugin_create_date>" & vbCrLf & _
        "<plugin_updated_by>" & plugin_updated_by & "</plugin_updated_by>" & vbCrLf & _
        "<plugin_update_date>" & plugin_update_date & "</plugin_update_date>" & vbCrLf & _
        "<plugin_version>" & plugin_version & "</plugin_version>" & vbCrLf & _
        "<plugin_protocol>" & plugin_protocol & "</plugin_protocol>" & vbCrLf & _
        "<plugin_port>" & plugin_port & "</plugin_port>" & vbCrLf & _
        "<plugin_request>" & plugin_request & "</plugin_request>" & vbCrLf & _
        "<plugin_trigger>" & plugin_trigger & "</plugin_trigger>" & vbCrLf & _
        "<plugin_comment>" & plugin_comment & "</plugin_comment>" & vbCrLf
     
     PluginContent = PluginContent & _
        "<bug_published_by>" & bug_published_by & "</bug_published_by>" & vbCrLf & _
        "<bug_date_published>" & bug_date_published & "</bug_date_published>" & vbCrLf & _
        "<bug_advisory>" & bug_advisory & "</bug_advisory>" & vbCrLf & _
        "<bug_affected>" & bug_affected & "</bug_affected>" & vbCrLf & _
        "<bug_not_affected>" & bug_not_affected & "<bug_not_affected>" & vbCrLf & _
        "<bug_vulnerability_class>" & bug_vulnerability_class & "</bug_vulnerability_class>" & vbCrLf & _
        "<bug_description>" & bug_description & "</bug_description>" & vbCrLf & _
        "<bug_solution>" & bug_solution & "</bug_solution>" & vbCrLf & _
        "<bug_fixing_time>" & bug_fixing_time & "</bug_fixing_time>" & vbCrLf & _
        "<bug_exploit_availability>" & bug_exploit_availability & "</bug_exploit_availability>" & vbCrLf & _
        "<bug_exploit_url>" & bug_exploit_url & "</bug_exploit_url>" & vbCrLf & _
        "<bug_remote>" & bug_remote & "</bug_remote>" & vbCrLf & _
        "<bug_local>" & bug_local & "</bug_local>" & vbCrLf & _
        "<bug_severity>" & bug_severity & "</bug_severity>" & vbCrLf & _
        "<bug_popularity>" & bug_popularity & "</bug_popularity>" & vbCrLf & _
        "<bug_simplicity>" & bug_simplicity & "</bug_simplicity>" & vbCrLf & _
        "<bug_impact>" & bug_impact & "</bug_impact>" & vbCrLf & _
        "<bug_risk>" & bug_risk & "</bug_risk>" & vbCrLf & _
        "<bug_nessus_risk>" & bug_nessus_risk & "</bug_nessus_risk>" & vbCrLf & _
        "<bug_iss_scanner_rating>" & bug_iss_scanner_rating & "</bug_iss_scanner_rating>" & vbCrLf & _
        "<bug_netrecon_rating>" & bug_netrecon_rating & "</bug_netrecon_rating>" & vbCrLf & _
        "<bug_check_tool>" & bug_check_tool & "</bug_check_tool>" & vbCrLf

    
     PluginContent = PluginContent & _
        "<source_cve>" & source_cve & "</source_cve>" & vbCrLf & _
        "<source_securityfocus_bid>" & source_securityfocus_bid & "</source_securityfocus_bid>" & vbCrLf & _
        "<source_secunia_id>" & source_secunia_id & "</source_secunia_id>" & vbCrLf & _
        "<source_scipid>" & source_scipid & "</source_scipid>" & vbCrLf & _
        "<source_tecchannel_id>" & source_tecchannel_id & "</source_tecchannel_id>" & vbCrLf & _
        "<source_heise_news>" & source_heise_news & "</source_heise_news>" & vbCrLf & _
        "<source_heise_security>" & source_heise_security & "</source_heise_security>" & vbCrLf & _
        "<source_aerasec_id>" & source_aerasec_id & "</source_aerasec_id>" & vbCrLf & _
        "<source_securiteam>" & source_securiteam & "</source_securiteam>" & vbCrLf & _
        "<source_nessus_id>" & source_nessus_id & "</source_nessus_id>" & vbCrLf & _
        "<source_snort_id>" & source_snort_id & "</source_snort_id>" & vbCrLf & _
        "<source_literature>" & source_literature & "</source_literature>" & vbCrLf & _
        "<source_misc>" & source_misc & "</source_misc>"
        
    'Kill all useless lines to save space and increase performance
    PluginContentArray = Split(PluginContent, vbCrLf)
    PluginContent = vbNullString
      
    For i = 0 To (UBound(PluginContentArray) - LBound(PluginContentArray) + 1) - 1
        If InStr(1, PluginContentArray(i), "></") = 0 Then
            PluginContent = PluginContent & PluginContentArray(i) & vbCrLf
        End If
    Next i
        
    'Write the collected data into the file; the plugin name will be the file name
    Open PluginDirectory & "/" & Filename & ".plugin" For Output As 1
        Print #1, PluginContent
    Close

End Sub
